LdlDecomposition

Struct LdlDecomposition 

pub struct LdlDecomposition { /* private fields */ }
The LDLᵀ decomposition of a symmetric matrix.

Implementations

Source

impl LdlDecomposition

pub fn zero(len: usize) -> Self

An unfactorized decomposition sized to hold that of a matrix of the given length.

pub fn solve(&self, b: &Vector) -> Vector

Solve a system of linear equations for another right-hand side.

pub fn solve_into(&self, b: &Vector, x: &mut Vector)

Solve a system of linear equations into an existing vector.