ContractAllWithFirst

Trait ContractAllWithFirst 

pub trait ContractAllWithFirst<TIM, TJN, TKO, TLP> {
    type Output;

    // Required method
    fn contract_all_with_first(
        self,
        object_a: TIM,
        object_b: TJN,
        object_c: TKO,
        object_d: TLP,
    ) -> Self::Output;
}
Transforms all four indices of a rank-4 tensor.

Contracts each index of self with the first index of a corresponding rank-2 tensor.

Required Associated Types

Required Methods

fn contract_all_with_first( self, object_a: TIM, object_b: TJN, object_c: TKO, object_d: TLP, ) -> Self::Output

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<const D: usize, I, J, K, L, M, N, O, P, U> ContractAllWithFirst<&TensorRank2<D, I, M>, &TensorRank2<D, J, N>, &TensorRank2<D, K, O>, &TensorRank2<D, L, P>> for TensorRank4<D, I, J, K, L, U>

Source

type Output = TensorRank4<D, M, N, O, P, U>