ContractFirstSecondWithSecond

Trait ContractFirstSecondWithSecond 

pub trait ContractFirstSecondWithSecond<TI, TJ> {
    type Output;

    // Required method
    fn contract_first_second_with_second(
        self,
        object_a: TI,
        object_b: TJ,
    ) -> Self::Output;
}
Transforms the first and second indices of a rank-4 tensor.

Contracts each with the second index of a corresponding rank-2 tensor.

Required Associated Types

Required Methods

fn contract_first_second_with_second( self, object_a: TI, object_b: TJ, ) -> Self::Output

Implementors

Source

impl<const D: usize, const I: usize, const J: usize, const K: usize, const L: usize, const M: usize, const N: usize> ContractFirstSecondWithSecond<&TensorRank2<D, I, M>, &TensorRank2<D, J, N>> for TensorRank4<D, M, N, K, L>

Source

type Output = TensorRank4<D, I, J, K, L>