pub trait ContractFirstThirdFourthWithFirst<TIM, TKO, TLP> {
type Output;
// Required method
fn contract_first_third_fourth_with_first(
self,
tensor_rank_2_a: TIM,
tensor_rank_2_c: TKO,
tensor_rank_2_d: TLP,
) -> Self::Output;
}Expand description
Transforms the first, third, and fourth indices of a rank-4 tensor.
Contracts each with the first index of a corresponding rank-2 tensor;
the second index of self is left untouched.