ContractThirdFourthWithFirstSecond

Trait ContractThirdFourthWithFirstSecond 

pub trait ContractThirdFourthWithFirstSecond<TKL> {
    type Output;

    // Required method
    fn contract_third_fourth_with_first_second(
        self,
        tensor: TKL,
    ) -> Self::Output;
}
Double-contracts the third and fourth indices of a rank-4 tensor.

Contracts against the leading two indices of another rank-2 or rank-4 tensor.

Required Associated Types

Required Methods

Implementors

Source

impl<const D: usize, const I: usize, const J: usize, const K: usize, const L: usize> ContractThirdFourthWithFirstSecond<&TensorRank2<D, K, L>> for TensorRank4<D, I, J, K, L>

Source

type Output = TensorRank2<D, I, J>

Source

impl<const D: usize, const I: usize, const J: usize, const K: usize, const L: usize, const M: usize, const N: usize> ContractThirdFourthWithFirstSecond<&TensorRank4<D, K, L, M, N>> for TensorRank4<D, I, J, K, L>

Source

type Output = TensorRank4<D, I, J, M, N>