Rank2

Trait Rank2 

pub trait Rank2
where Self: Sized + Tensor,
{ type Transpose; // Required methods fn deviatoric(&self) -> Self; fn deviatoric_and_trace(&self) -> (Self, Quantity<Self::Unit>); fn is_diagonal(&self) -> bool; fn is_identity(&self) -> bool; fn is_symmetric(&self) -> bool; fn squared_trace(&self) -> Quantity<Square<Self::Unit>> where Self::Unit: UnitMul<Self::Unit>; fn trace(&self) -> Quantity<Self::Unit>; fn transpose(&self) -> Self::Transpose; // Provided method fn second_invariant(&self) -> Quantity<Square<Self::Unit>> where Self::Unit: UnitMul<Self::Unit> { ... } }
Common methods for rank-2 tensors.

Required Associated Types

type Transpose

The type that is the transpose of the tensor.

Required Methods

fn deviatoric(&self) -> Self

Returns the deviatoric component of the rank-2 tensor.

fn deviatoric_and_trace(&self) -> (Self, Quantity<Self::Unit>)

Returns the deviatoric component and trace of the rank-2 tensor.

fn is_diagonal(&self) -> bool

Checks whether the tensor is a diagonal tensor.

fn is_identity(&self) -> bool

Checks whether the tensor is the identity tensor.

fn is_symmetric(&self) -> bool

Checks whether the tensor is a symmetric tensor.

fn squared_trace(&self) -> Quantity<Square<Self::Unit>>
where Self::Unit: UnitMul<Self::Unit>,

Returns the trace of the rank-2 tensor squared.

fn trace(&self) -> Quantity<Self::Unit>

Returns the trace of the rank-2 tensor, which carries its unit.

fn transpose(&self) -> Self::Transpose

Returns the transpose of the rank-2 tensor.

Provided Methods

fn second_invariant(&self) -> Quantity<Square<Self::Unit>>
where Self::Unit: UnitMul<Self::Unit>,

Returns the second invariant of the rank-2 tensor.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Rank2 for SquareMatrix

Source

impl<const D: usize, I, J, U> Rank2 for TensorRank2<D, I, J, U>

Source

type Transpose = TensorRank2<D, J, I, U>