pub trait Solution{
// Required methods
fn decrement_from(&mut self, other: &Vector);
fn decrement_from_chained(&mut self, other: &mut Vector, vector: &Vector);
// Provided method
fn decrement_from_retained(&mut self, _retained: &[bool], _other: &Vector) { ... }
}Expand description
Common methods for solutions.
Required Methods
Sourcefn decrement_from(&mut self, other: &Vector)
fn decrement_from(&mut self, other: &Vector)
Decrements the solution from another vector.
Sourcefn decrement_from_chained(&mut self, other: &mut Vector, vector: &Vector)
fn decrement_from_chained(&mut self, other: &mut Vector, vector: &Vector)
Decrements the solution chained with a vector from another vector.
Provided Methods
Sourcefn decrement_from_retained(&mut self, _retained: &[bool], _other: &Vector)
fn decrement_from_retained(&mut self, _retained: &[bool], _other: &Vector)
Decrements the solution from another vector on retained entries.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".