Derivative

Type Alias Derivative 

pub type Derivative<Y, T = Time> = <Y as Differentiate<T>>::Derivative;
The derivative of Y with respect to a variable of unit T.

Spelling the projection out at every use would crowd out the signatures it appears in, since a tensor names a derivative for each variable it might be differentiated against.