pub struct LdlDecomposition { /* private fields */ }Expand description
The LDLᵀ decomposition of a symmetric matrix.
Implementations
Sourceimpl LdlDecomposition
impl LdlDecomposition
Sourcepub fn zero(len: usize) -> Self
pub fn zero(len: usize) -> Self
An unfactorized decomposition sized to hold that of a matrix of the given length.
Sourcepub fn solve(&self, b: &Vector) -> Vector
pub fn solve(&self, b: &Vector) -> Vector
Solve a system of linear equations for another right-hand side.
Sourcepub fn solve_into(&self, b: &Vector, x: &mut Vector)
pub fn solve_into(&self, b: &Vector, x: &mut Vector)
Solve a system of linear equations into an existing vector.