pub struct Quantity<U = Dimensionless>(/* private fields */);Expand description
A scalar carrying a physical unit.
Implementations
Sourceimpl<U> Quantity<U>
impl<U> Quantity<U>
Sourcepub const fn value(&self) -> TensorRank0
pub const fn value(&self) -> TensorRank0
Returns the value with its unit discarded.
Sourcepub const fn value_as<V>(&self) -> TensorRank0where
U: Is<V>,
pub const fn value_as<V>(&self) -> TensorRank0where
U: Is<V>,
Returns the value, stating the unit being discarded.
Sourceimpl<U> Quantity<U>
impl<U> Quantity<U>
Sourcepub fn differs(self, quantity: Self, epsilon: TensorRank0) -> bool
pub fn differs(self, quantity: Self, epsilon: TensorRank0) -> bool
Returns whether two quantities differ by more than the epsilon relatively, at least one of them being large enough for that ratio to mean anything.
Sourcepub fn differs_severely(self, quantity: Self, epsilon: TensorRank0) -> bool
pub fn differs_severely(self, quantity: Self, epsilon: TensorRank0) -> bool
Returns whether two quantities differ absolutely as well as relatively.
Sourcepub fn total_cmp(&self, quantity: &Self) -> Ordering
pub fn total_cmp(&self, quantity: &Self) -> Ordering
Returns how two quantities of the same unit order, totally.
Sourceimpl<U> Quantity<U>where
U: UnitHalves,
impl<U> Quantity<U>where
U: UnitHalves,
Sourcepub const fn halves(
self,
) -> (Quantity<<U as UnitHalves>::First>, Quantity<<U as UnitHalves>::Second>)
pub const fn halves( self, ) -> (Quantity<<U as UnitHalves>::First>, Quantity<<U as UnitHalves>::Second>)
Returns the quantity twice over, as the units the halves of a tuple take from it.
Sourceimpl Quantity<Dimensionless>
impl Quantity<Dimensionless>
Sourcepub fn powf(self, n: TensorRank0) -> Self
pub fn powf(self, n: TensorRank0) -> Self
Raises to a power.
Sourceimpl Quantity<Length>
impl Quantity<Length>
Sourcepub const fn in_meters(&self) -> TensorRank0
pub const fn in_meters(&self) -> TensorRank0
How many metres the quantity is.
Sourcepub const fn in_millimeters(&self) -> TensorRank0
pub const fn in_millimeters(&self) -> TensorRank0
How many millimetres the quantity is.
Sourcepub const fn in_micrometers(&self) -> TensorRank0
pub const fn in_micrometers(&self) -> TensorRank0
How many micrometres the quantity is.
Sourcepub const fn in_nanometers(&self) -> TensorRank0
pub const fn in_nanometers(&self) -> TensorRank0
How many nanometres the quantity is.
Sourcepub const fn in_centimeters(&self) -> TensorRank0
pub const fn in_centimeters(&self) -> TensorRank0
How many centimetres the quantity is.
Sourcepub const fn in_kilometers(&self) -> TensorRank0
pub const fn in_kilometers(&self) -> TensorRank0
How many kilometres the quantity is.
Sourcepub const fn in_inches(&self) -> TensorRank0
pub const fn in_inches(&self) -> TensorRank0
How many inches the quantity is.
Sourcepub const fn in_feet(&self) -> TensorRank0
pub const fn in_feet(&self) -> TensorRank0
How many feet the quantity is.
Sourceimpl Quantity<Area>
impl Quantity<Area>
Sourcepub const fn in_square_meters(&self) -> TensorRank0
pub const fn in_square_meters(&self) -> TensorRank0
How many square metres the quantity is.
Sourcepub const fn in_square_millimeters(&self) -> TensorRank0
pub const fn in_square_millimeters(&self) -> TensorRank0
How many square millimetres the quantity is.
Sourcepub const fn in_square_centimeters(&self) -> TensorRank0
pub const fn in_square_centimeters(&self) -> TensorRank0
How many square centimetres the quantity is.
Sourceimpl Quantity<Volume>
impl Quantity<Volume>
Sourcepub const fn in_cubic_meters(&self) -> TensorRank0
pub const fn in_cubic_meters(&self) -> TensorRank0
How many cubic metres the quantity is.
Sourcepub const fn in_cubic_millimeters(&self) -> TensorRank0
pub const fn in_cubic_millimeters(&self) -> TensorRank0
How many cubic millimetres the quantity is.
Sourcepub const fn in_cubic_centimeters(&self) -> TensorRank0
pub const fn in_cubic_centimeters(&self) -> TensorRank0
How many cubic centimetres the quantity is.
Sourcepub const fn in_liters(&self) -> TensorRank0
pub const fn in_liters(&self) -> TensorRank0
How many litres the quantity is.
Sourceimpl Quantity<Time>
impl Quantity<Time>
Sourcepub const fn in_seconds(&self) -> TensorRank0
pub const fn in_seconds(&self) -> TensorRank0
How many seconds the quantity is.
Sourcepub const fn in_milliseconds(&self) -> TensorRank0
pub const fn in_milliseconds(&self) -> TensorRank0
How many milliseconds the quantity is.
Sourcepub const fn in_microseconds(&self) -> TensorRank0
pub const fn in_microseconds(&self) -> TensorRank0
How many microseconds the quantity is.
Sourcepub const fn in_minutes(&self) -> TensorRank0
pub const fn in_minutes(&self) -> TensorRank0
How many minutes the quantity is.
Sourcepub const fn in_hours(&self) -> TensorRank0
pub const fn in_hours(&self) -> TensorRank0
How many hours the quantity is.
Sourceimpl Quantity<Rate>
impl Quantity<Rate>
Sourcepub const fn in_per_second(&self) -> TensorRank0
pub const fn in_per_second(&self) -> TensorRank0
How many reciprocal seconds the quantity is.
Sourcepub const fn in_per_minute(&self) -> TensorRank0
pub const fn in_per_minute(&self) -> TensorRank0
How many reciprocal minutes the quantity is.
Sourcepub const fn in_per_hour(&self) -> TensorRank0
pub const fn in_per_hour(&self) -> TensorRank0
How many reciprocal hours the quantity is.
Sourcepub const fn in_hertz(&self) -> TensorRank0
pub const fn in_hertz(&self) -> TensorRank0
How many hertz the quantity is.
Sourceimpl Quantity<Stress>
impl Quantity<Stress>
Sourcepub const fn in_pascals(&self) -> TensorRank0
pub const fn in_pascals(&self) -> TensorRank0
How many pascals the quantity is.
Sourcepub const fn in_kilopascals(&self) -> TensorRank0
pub const fn in_kilopascals(&self) -> TensorRank0
How many kilopascals the quantity is.
Sourcepub const fn in_megapascals(&self) -> TensorRank0
pub const fn in_megapascals(&self) -> TensorRank0
How many megapascals the quantity is.
Sourcepub const fn in_gigapascals(&self) -> TensorRank0
pub const fn in_gigapascals(&self) -> TensorRank0
How many gigapascals the quantity is.
Sourcepub const fn in_bars(&self) -> TensorRank0
pub const fn in_bars(&self) -> TensorRank0
How many bars the quantity is.
Sourcepub const fn in_psi(&self) -> TensorRank0
pub const fn in_psi(&self) -> TensorRank0
How many pounds per square inch the quantity is.
Sourcepub const fn in_ksi(&self) -> TensorRank0
pub const fn in_ksi(&self) -> TensorRank0
How many kips per square inch the quantity is.
Sourceimpl Quantity<Force>
impl Quantity<Force>
Sourcepub const fn in_newtons(&self) -> TensorRank0
pub const fn in_newtons(&self) -> TensorRank0
How many newtons the quantity is.
Sourcepub const fn in_millinewtons(&self) -> TensorRank0
pub const fn in_millinewtons(&self) -> TensorRank0
How many millinewtons the quantity is.
Sourcepub const fn in_kilonewtons(&self) -> TensorRank0
pub const fn in_kilonewtons(&self) -> TensorRank0
How many kilonewtons the quantity is.
Sourcepub const fn in_meganewtons(&self) -> TensorRank0
pub const fn in_meganewtons(&self) -> TensorRank0
How many meganewtons the quantity is.
Sourcepub const fn in_pounds_force(&self) -> TensorRank0
pub const fn in_pounds_force(&self) -> TensorRank0
How many pounds force the quantity is.
Sourceimpl Quantity<Energy>
impl Quantity<Energy>
Sourcepub const fn in_joules(&self) -> TensorRank0
pub const fn in_joules(&self) -> TensorRank0
How many joules the quantity is.
Sourcepub const fn in_millijoules(&self) -> TensorRank0
pub const fn in_millijoules(&self) -> TensorRank0
How many millijoules the quantity is.
Sourcepub const fn in_kilojoules(&self) -> TensorRank0
pub const fn in_kilojoules(&self) -> TensorRank0
How many kilojoules the quantity is.
Sourcepub const fn in_electronvolts(&self) -> TensorRank0
pub const fn in_electronvolts(&self) -> TensorRank0
How many electronvolts the quantity is.
Sourceimpl Quantity<Entropy>
impl Quantity<Entropy>
Sourcepub const fn in_joules_per_kelvin(&self) -> TensorRank0
pub const fn in_joules_per_kelvin(&self) -> TensorRank0
How many joules per kelvin the quantity is.
Sourceimpl Quantity<Action>
impl Quantity<Action>
Sourcepub const fn in_joule_seconds(&self) -> TensorRank0
pub const fn in_joule_seconds(&self) -> TensorRank0
How many joule seconds the quantity is.
Sourceimpl Quantity<Amount>
impl Quantity<Amount>
Sourcepub const fn in_moles(&self) -> TensorRank0
pub const fn in_moles(&self) -> TensorRank0
How many moles the quantity is.
Sourcepub const fn in_millimoles(&self) -> TensorRank0
pub const fn in_millimoles(&self) -> TensorRank0
How many millimoles the quantity is.
Sourceimpl Quantity<ReciprocalAmount>
impl Quantity<ReciprocalAmount>
Sourcepub const fn in_per_mole(&self) -> TensorRank0
pub const fn in_per_mole(&self) -> TensorRank0
How many reciprocal moles the quantity is.
Sourceimpl Quantity<MolarEntropy>
impl Quantity<MolarEntropy>
Sourcepub const fn in_joules_per_mole_kelvin(&self) -> TensorRank0
pub const fn in_joules_per_mole_kelvin(&self) -> TensorRank0
How many joules per mole kelvin the quantity is.
Sourceimpl Quantity<MolarEnergy>
impl Quantity<MolarEnergy>
Sourcepub const fn in_joules_per_mole(&self) -> TensorRank0
pub const fn in_joules_per_mole(&self) -> TensorRank0
How many joules per mole the quantity is.
Sourcepub const fn in_kilojoules_per_mole(&self) -> TensorRank0
pub const fn in_kilojoules_per_mole(&self) -> TensorRank0
How many kilojoules per mole the quantity is.
Sourceimpl Quantity<ForcePerLength>
impl Quantity<ForcePerLength>
Sourcepub const fn in_newtons_per_meter(&self) -> TensorRank0
pub const fn in_newtons_per_meter(&self) -> TensorRank0
How many newtons per metre the quantity is.
Sourcepub const fn in_piconewtons_per_nanometer(&self) -> TensorRank0
pub const fn in_piconewtons_per_nanometer(&self) -> TensorRank0
How many piconewtons per nanometre the quantity is.
Sourceimpl Quantity<Velocity>
impl Quantity<Velocity>
Sourcepub const fn in_meters_per_second(&self) -> TensorRank0
pub const fn in_meters_per_second(&self) -> TensorRank0
How many metres per second the quantity is.
Sourcepub const fn in_millimeters_per_second(&self) -> TensorRank0
pub const fn in_millimeters_per_second(&self) -> TensorRank0
How many millimetres per second the quantity is.
Sourcepub const fn in_kilometers_per_hour(&self) -> TensorRank0
pub const fn in_kilometers_per_hour(&self) -> TensorRank0
How many kilometres per hour the quantity is.
Sourceimpl Quantity<Charge>
impl Quantity<Charge>
Sourcepub const fn in_coulombs(&self) -> TensorRank0
pub const fn in_coulombs(&self) -> TensorRank0
How many coulombs the quantity is.
Sourceimpl Quantity<Viscosity>
impl Quantity<Viscosity>
Sourcepub const fn in_pascal_seconds(&self) -> TensorRank0
pub const fn in_pascal_seconds(&self) -> TensorRank0
How many pascal seconds the quantity is.
Sourcepub const fn in_poise(&self) -> TensorRank0
pub const fn in_poise(&self) -> TensorRank0
How many poise the quantity is.
Sourcepub const fn in_centipoise(&self) -> TensorRank0
pub const fn in_centipoise(&self) -> TensorRank0
How many centipoise the quantity is.
Sourceimpl Quantity<Temperature>
impl Quantity<Temperature>
Sourcepub const fn in_kelvin(&self) -> TensorRank0
pub const fn in_kelvin(&self) -> TensorRank0
How many kelvin the quantity is.
Sourceimpl Quantity<ReciprocalTemperature>
impl Quantity<ReciprocalTemperature>
Sourcepub const fn in_per_kelvin(&self) -> TensorRank0
pub const fn in_per_kelvin(&self) -> TensorRank0
How many reciprocal kelvin the quantity is.
Sourcepub const fn in_per_celsius(&self) -> TensorRank0
pub const fn in_per_celsius(&self) -> TensorRank0
How many reciprocal degrees celsius the quantity is.
Sourceimpl Quantity<StressPerLength>
impl Quantity<StressPerLength>
Sourcepub const fn in_pascals_per_meter(&self) -> TensorRank0
pub const fn in_pascals_per_meter(&self) -> TensorRank0
How many pascals per metre the quantity is.
Sourcepub const fn in_megapascals_per_millimeter(&self) -> TensorRank0
pub const fn in_megapascals_per_millimeter(&self) -> TensorRank0
How many megapascals per millimetre the quantity is.
Sourceimpl Quantity<PowerPerLengthTemperature>
impl Quantity<PowerPerLengthTemperature>
Sourcepub const fn in_watts_per_meter_kelvin(&self) -> TensorRank0
pub const fn in_watts_per_meter_kelvin(&self) -> TensorRank0
How many watts per metre kelvin the quantity is.
Sourceimpl Quantity<Dimensionless>
impl Quantity<Dimensionless>
Sourcepub const fn in_percent(&self) -> TensorRank0
pub const fn in_percent(&self) -> TensorRank0
How many percent the quantity is.
Sourceimpl Quantity<Temperature>
impl Quantity<Temperature>
Sourcepub const fn in_celsius(&self) -> TensorRank0
pub const fn in_celsius(&self) -> TensorRank0
How many degrees celsius the temperature is.
Sourcepub const fn in_fahrenheit(&self) -> TensorRank0
pub const fn in_fahrenheit(&self) -> TensorRank0
How many degrees fahrenheit the temperature is.