pub trait ContractFirstSecondWithSecond<TI, TJ> {
type Output;
// Required method
fn contract_first_second_with_second(
self,
object_a: TI,
object_b: TJ,
) -> Self::Output;
}Expand description
Transforms the first and second indices of a rank-4 tensor.
Contracts each with the second index of a corresponding rank-2 tensor.