pub trait ContractThirdFourthWithFirstSecond<TKL> {
type Output;
// Required method
fn contract_third_fourth_with_first_second(
self,
tensor: TKL,
) -> Self::Output;
}Expand description
Double-contracts the third and fourth indices of a rank-4 tensor.
Contracts against the leading two indices of another rank-2 or rank-4 tensor.