HessianBlock

Trait HessianBlock 

pub trait HessianBlock {
    // Required methods
    fn entry(&self, row: usize, column: usize) -> TensorRank0;
    fn height(&self) -> usize;
    fn width(&self) -> usize;
    fn fill_into_block<M>(&self, matrix: &mut M, row: usize, column: usize)
       where M: IndexMut<usize, Output = Vector>;
}
Common methods for blocks of a Hessian.

Required Methods

fn entry(&self, row: usize, column: usize) -> TensorRank0

The entry of the block at the given row and column within it.

fn height(&self) -> usize

The number of rows the block occupies.

fn width(&self) -> usize

The number of columns the block occupies.

fn fill_into_block<M>(&self, matrix: &mut M, row: usize, column: usize)
where M: IndexMut<usize, Output = Vector>,

Fills the block into a matrix at the given row and column offsets.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<const D: usize, I, J, K, L, U> HessianBlock for TensorRank4<D, I, J, K, L, U>