pub trait Is<T> { }Expand description
Implemented only where the two types are the same, so that a unit may be named where it is discarded without allowing a different one.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".