Is

Trait Is 

pub trait Is<T> { }
Implemented only where the two types are the same, so that a unit may be named where it is discarded without allowing a different one.

Implementors

Source

impl<T> Is<T> for T