pub trait TensorVec{
type Item;
// Required methods
fn append(&mut self, other: &mut Self);
fn capacity(&self) -> usize;
fn is_empty(&self) -> bool;
fn new() -> Self;
fn push(&mut self, item: Self::Item);
fn remove(&mut self, index: usize) -> Self::Item;
fn reserve(&mut self, additional: usize);
fn retain<F>(&mut self, f: F)
where F: FnMut(&Self::Item) -> bool;
fn swap_remove(&mut self, index: usize) -> Self::Item;
fn with_capacity(capacity: usize) -> Self;
}Expand description
Common methods for tensors derived from Vec.
Required Associated Types
Required Methods
Sourcefn append(&mut self, other: &mut Self)
fn append(&mut self, other: &mut Self)
Moves all the elements of other into self, leaving other empty.
Sourcefn capacity(&self) -> usize
fn capacity(&self) -> usize
Returns the total number of elements the vector can hold without reallocating.
Sourcefn new() -> Self
fn new() -> Self
Constructs a new, empty Vec, not allocating until elements are pushed onto it.
Sourcefn remove(&mut self, index: usize) -> Self::Item
fn remove(&mut self, index: usize) -> Self::Item
Removes an element from the Vec and returns it, shifting elements to the left.
Sourcefn reserve(&mut self, additional: usize)
fn reserve(&mut self, additional: usize)
Reserves capacity for at least additional more elements to be inserted in the given Vec.
Sourcefn swap_remove(&mut self, index: usize) -> Self::Item
fn swap_remove(&mut self, index: usize) -> Self::Item
Removes an element from the Vec and returns it, replacing it with the last element.
Sourcefn with_capacity(capacity: usize) -> Self
fn with_capacity(capacity: usize) -> Self
Constructs a new, empty vector with at least the specified capacity.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".